@@ -54,7 +54,7 @@ find_external_resources <- function(input_file, encoding = 'UTF-8') {
 
   # ensure we're working with valid input
   ext <- tolower(xfun::file_ext(input_file))
-  if (!(ext %in% c("md", "rmd", "html", "htm", "r", "css"))) {
+  if (!(ext %in% c("md", "rmd", "qmd", "html", "htm", "r", "css"))) {
     stop("Resource discovery is only supported for R Markdown files or HTML files.")
   }
 
@@ -101,7 +101,7 @@ find_external_resources <- function(input_file, encoding = 'UTF-8') {
   }
 
   # run the main resource discovery appropriate to the file type
-  if (ext %in% c("md", "rmd")) {
+  if (ext %in% c("md", "rmd", "qmd")) {
     # discover R Markdown doc resources--scans the document itself as described
     # in comments above, renders as Markdown, and invokes HTML discovery
     # on the result
@@ -299,7 +299,7 @@ discover_rmd_resources <- function(rmd_file, discover_single_resource) {
   }
 
   # check for knitr child documents in R Markdown documents
-  if (tolower(xfun::file_ext(rmd_file)) == "rmd") {
+  if (tolower(xfun::file_ext(rmd_file)) %in% c("qmd", "rmd")) {
     chunk_lines <- gregexpr(knitr::all_patterns$md$chunk.begin, rmd_content, perl = TRUE)
     for (idx in seq_along(chunk_lines)) {
       chunk_line <- chunk_lines[idx][[1]]
@@ -351,7 +351,7 @@ discover_rmd_resources <- function(rmd_file, discover_single_resource) {
   discover_html_resources(html_file, discover_single_resource)
 
   # if this is an R Markdown file, purl the file to extract just the R code
-  if (tolower(xfun::file_ext(rmd_file)) == "rmd") {
+  if (tolower(xfun::file_ext(rmd_file)) %in% c("qmd", "rmd")) {
     r_file <- tempfile(fileext = ".R")
     # suppress possible try() errors https://github.com/rstudio/rmarkdown/issues/1247
     try_file <- tempfile()
